==> jboss-as-naming-7.3.2.Final-redhat-2-sources.jar: org/jboss/as/naming/subsystem/RemoteNamingRemove.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.naming.subsystem;

import org.jboss.as.controller.AbstractRemoveStepHandler;
import org.jboss.as.controller.OperationContext;
import org.jboss.as.controller.OperationFailedException;
import org.jboss.as.naming.remote.RemoteNamingServerService;
import org.jboss.dmr.ModelNode;

/**
 * Handles removing a JNDI binding
 */
public class RemoteNamingRemove extends AbstractRemoveStepHandler {

    public static final RemoteNamingRemove INSTANCE = new RemoteNamingRemove();

    @Override
    protected void performRuntime(OperationContext context, ModelNode operation, ModelNode model) throws OperationFailedException {
        if (context.isResourceServiceRestartAllowed()) {
            removeRuntimeService(context);
        } else {
            context.reloadRequired();
        }
    }

    @Override
    protected void recoverServices(OperationContext context, ModelNode operation, ModelNode model) throws OperationFailedException {
        if (context.isResourceServiceRestartAllowed()) {
            RemoteNamingAdd.INSTANCE.installRuntimeServices(context, null, null);
        } else {
            context.revertReloadRequired();
        }
    }

    void removeRuntimeService(OperationContext context) {
        context.removeService(RemoteNamingServerService.SERVICE_NAME);
    }
}

==> jboss-as-naming-7.5.10.Final-redhat-2-sources.jar: org/jboss/as/naming/subsystem/RemoteNamingRemove.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.naming.subsystem;

import org.jboss.as.controller.ServiceRemoveStepHandler;
import org.jboss.as.naming.remote.RemoteNamingServerService;
import org.jboss.msc.service.ServiceName;

/**
 * Handles removing a JNDI binding
 */
public class RemoteNamingRemove extends ServiceRemoveStepHandler {

    public static final RemoteNamingRemove INSTANCE = new RemoteNamingRemove();

    private RemoteNamingRemove() {
        super(RemoteNamingAdd.INSTANCE);
    }

    @Override
    protected ServiceName serviceName(final String name) {
        return RemoteNamingServerService.SERVICE_NAME;
    }
}
